@@ -1,5 +1,10 @@
+use async_trait::async_trait;
 use serde::{Deserialize, Serialize};
+use serde_json::Value;
 
+use crate::persist::{
+    PersistedEventRepository, PersistenceError, SerializedEvent, SerializedSnapshot,
+};
 use crate::{Aggregate, AggregateError, DomainEvent, UserErrorPayload};
 
 #[derive(Debug, Serialize, Deserialize, PartialEq, Clone)]
@@ -7,11 +12,13 @@ pub enum MyEvents {
     SomethingWasDone,
 }
 impl DomainEvent for MyEvents {
-    fn event_type(&self) -> &'static str {
-        todo!()
+    fn event_type(&self) -> String {
+        match self {
+            MyEvents::SomethingWasDone => "SomethingWasDone".to_string(),
+        }
     }
-    fn event_version(&self) -> &'static str {
-        todo!()
+    fn event_version(&self) -> String {
+        "0.1.0".to_string()
     }
 }
 #[derive(Debug, Serialize, Deserialize)]
@@ -21,16 +28,18 @@ pub enum MyCommands {
 }
 #[derive(Debug, Default, Serialize, Deserialize)]
 pub struct MyAggregate;
+
+#[async_trait]
 impl Aggregate for MyAggregate {
     type Command = MyCommands;
     type Event = MyEvents;
     type Error = UserErrorPayload;
 
-    fn aggregate_type() -> &'static str {
-        todo!()
+    fn aggregate_type() -> String {
+        "MyAggregate".to_string()
     }
 
-    fn handle(
+    async fn handle(
         &self,
         command: Self::Command,
     ) -> Result<Vec<Self::Event>, AggregateError<UserErrorPayload>> {
@@ -50,33 +59,36 @@ pub struct Customer {
     pub email: String,
 }
 
+#[async_trait]
 impl Aggregate for Customer {
     type Command = CustomerCommand;
     type Event = CustomerEvent;
     type Error = UserErrorPayload;
 
-    fn aggregate_type() -> &'static str {
-        "customer"
+    fn aggregate_type() -> String {
+        "Customer".to_string()
     }
 
-    fn handle(
+    async fn handle(
         &self,
         command: Self::Command,
     ) -> Result<Vec<Self::Event>, AggregateError<Self::Error>> {
         match command {
-            CustomerCommand::AddCustomerName { changed_name } => {
+            CustomerCommand::AddCustomerName { name: changed_name } => {
                 if self.name.as_str() != "" {
                     return Err("a name has already been added for this customer".into());
                 }
-                Ok(vec![CustomerEvent::NameAdded { changed_name }])
+                Ok(vec![CustomerEvent::NameAdded { name: changed_name }])
+            }
+            CustomerCommand::UpdateEmail { new_email } => {
+                Ok(vec![CustomerEvent::EmailUpdated { new_email }])
             }
-            CustomerCommand::UpdateEmail { .. } => Ok(Default::default()),
         }
     }
 
     fn apply(&mut self, event: Self::Event) {
         match event {
-            CustomerEvent::NameAdded { changed_name } => {
+            CustomerEvent::NameAdded { name: changed_name } => {
                 self.name = changed_name;
             }
             CustomerEvent::EmailUpdated { new_email } => {
@@ -98,26 +110,26 @@ impl Default for Customer {
 
 #[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 pub enum CustomerEvent {
-    NameAdded { changed_name: String },
+    NameAdded { name: String },
     EmailUpdated { new_email: String },
 }
 
 impl DomainEvent for CustomerEvent {
-    fn event_type(&self) -> &'static str {
+    fn event_type(&self) -> String {
         match self {
-            CustomerEvent::NameAdded { .. } => "NameAdded",
-            CustomerEvent::EmailUpdated { .. } => "EmailUpdated",
+            CustomerEvent::NameAdded { .. } => "NameAdded".to_string(),
+            CustomerEvent::EmailUpdated { .. } => "EmailUpdated".to_string(),
         }
     }
 
-    fn event_version(&self) -> &'static str {
-        "1.0"
+    fn event_version(&self) -> String {
+        "1.0".to_string()
     }
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 pub enum CustomerCommand {
-    AddCustomerName { changed_name: String },
+    AddCustomerName { name: String },
     UpdateEmail { new_email: String },
 }
 
@@ -134,10 +146,10 @@ mod doc_tests {
         CustomerTestFramework::default()
             .given_no_previous_events()
             .when(CustomerCommand::AddCustomerName {
-                changed_name: "John Doe".to_string(),
+                name: "John Doe".to_string(),
             })
             .then_expect_events(vec![CustomerEvent::NameAdded {
-                changed_name: "John Doe".to_string(),
+                name: "John Doe".to_string(),
             }]);
     }
 
@@ -145,11 +157,45 @@ mod doc_tests {
     fn test_add_name_again() {
         CustomerTestFramework::default()
             .given(vec![CustomerEvent::NameAdded {
-                changed_name: "John Doe".to_string(),
+                name: "John Doe".to_string(),
             }])
             .when(CustomerCommand::AddCustomerName {
-                changed_name: "John Doe".to_string(),
+                name: "John Doe".to_string(),
             })
-            .then_expect_error("a name has already been added for this customer");
+            .then_expect_error_message("a name has already been added for this customer");
+    }
+}
+
+pub struct MyRepository;
+#[async_trait]
+impl PersistedEventRepository for MyRepository {
+    async fn get_events<A: Aggregate>(
+        &self,
+        _aggregate_id: &str,
+    ) -> Result<Vec<SerializedEvent>, PersistenceError> {
+        todo!()
+    }
+
+    async fn get_last_events<A: Aggregate>(
+        &self,
+        _aggregate_id: &str,
+        _number_events: usize,
+    ) -> Result<Vec<SerializedEvent>, PersistenceError> {
+        todo!()
+    }
+
+    async fn get_snapshot<A: Aggregate>(
+        &self,
+        _aggregate_id: &str,
+    ) -> Result<Option<SerializedSnapshot>, PersistenceError> {
+        todo!()
+    }
+
+    async fn persist<A: Aggregate>(
+        &self,
+        _events: &[SerializedEvent],
+        _snapshot_update: Option<(String, Value, usize)>,
+    ) -> Result<(), PersistenceError> {
+        todo!()
     }
 }
