@@ -52,33 +52,26 @@ pub mod doc;
 /// ```
 pub mod mem_store;
 
+pub mod persist;
 /// Test provides a test framework for building a resilient test base around aggregates.
 /// A `TestFramework` should be used to build a comprehensive set of aggregate tests to verify
 /// your application logic.
 ///
-/// ```
+/// ```rust
 /// # use cqrs_es::test::TestFramework;
 /// # use cqrs_es::doc::{Customer, CustomerEvent, CustomerCommand};
+/// # fn test() {
 /// type CustomerTestFramework = TestFramework<Customer>;
 ///
 /// CustomerTestFramework::default()
 ///     .given_no_previous_events()
 ///     .when(CustomerCommand::AddCustomerName{
-///             changed_name: "John Doe".to_string()
+///             name: "John Doe".to_string()
 ///         })
 ///     .then_expect_events(vec![
 ///         CustomerEvent::NameAdded{
-///             changed_name: "John Doe".to_string()
+///             name: "John Doe".to_string()
 ///         }]);
-///
-/// CustomerTestFramework::default()
-///     .given(vec![
-///         CustomerEvent::NameAdded {
-///             changed_name: "John Doe".to_string()
-///         }])
-///     .when(CustomerCommand::AddCustomerName {
-///             changed_name: "John Doe".to_string()
-///         })
-///     .then_expect_error("a name has already been added for this customer")
+/// # }
 /// ```
 pub mod test;
