@@ -83,15 +83,23 @@ where
     /// let validator = executor.when(MyCommands::DoSomething);
     /// ```
     pub fn when(self, command: A::Command) -> AggregateResultValidator<A> {
-        let mut aggregate = A::default();
-        for event in self.events {
-            aggregate.apply(event);
-        }
-        let result = aggregate.handle(command);
+        let result = when::<A>(self.events, command);
         AggregateResultValidator { result }
     }
 }
 
+#[tokio::main]
+async fn when<A: Aggregate>(
+    events: Vec<A::Event>,
+    command: A::Command,
+) -> Result<Vec<A::Event>, AggregateError<A::Error>> {
+    let mut aggregate = A::default();
+    for event in events {
+        aggregate.apply(event);
+    }
+    aggregate.handle(command).await
+}
+
 /// Validation object for the `TestFramework` package.
 pub struct AggregateResultValidator<A>
 where
@@ -105,6 +113,7 @@ impl<A: Aggregate> AggregateResultValidator<A> {
     ///
     /// ```
     /// # use cqrs_es::doc::{MyAggregate, MyCommands, MyEvents};
+    /// # async fn test() {
     /// use cqrs_es::test::TestFramework;
     ///
     /// let validator = TestFramework::<MyAggregate>::default()
@@ -112,6 +121,7 @@ impl<A: Aggregate> AggregateResultValidator<A> {
     ///     .when(MyCommands::DoSomething);
     ///
     /// validator.then_expect_events(vec![MyEvents::SomethingWasDone]);
+    /// # }
     /// ```
     pub fn then_expect_events(self, expected_events: Vec<A::Event>) {
         let events = match self.result {
@@ -122,6 +132,40 @@ impl<A: Aggregate> AggregateResultValidator<A> {
         };
         assert_eq!(&events[..], &expected_events[..]);
     }
+
+    /// Verifies that the result is a `UserError` and returns the internal error payload for
+    /// further validation.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::{MyAggregate, MyCommands, MyEvents};
+    /// use cqrs_es::UserErrorPayload;
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let validator = TestFramework::<MyAggregate>::default()
+    ///     .given_no_previous_events()
+    ///     .when(MyCommands::BadCommand);
+    ///
+    /// let expected: UserErrorPayload = UserErrorPayload {
+    ///         message: Some("the expected error message".to_string()),
+    ///         code: None,
+    ///         params: None,
+    /// };
+    /// assert_eq!(expected,validator.then_expect_error());
+    /// ```
+    pub fn then_expect_error(self) -> A::Error {
+        match self.result {
+            Ok(events) => {
+                panic!("expected error, received events: '{:?}'", events);
+            }
+            Err(err) => match err {
+                AggregateError::UserError(err) => err,
+                _ => {
+                    panic!("expected user error but found technical error: {}", err)
+                }
+            },
+        }
+    }
+
     /// Verifies that an `AggregateError` with the expected message is produced with the command.
     ///
     /// ```
@@ -132,9 +176,9 @@ impl<A: Aggregate> AggregateResultValidator<A> {
     ///     .given_no_previous_events()
     ///     .when(MyCommands::BadCommand);
     ///
-    /// validator.then_expect_error("the expected error message");
+    /// validator.then_expect_error_message("the expected error message");
     /// ```
-    pub fn then_expect_error(self, error_message: &str) {
+    pub fn then_expect_error_message(self, error_message: &str) {
         match self.result {
             Ok(events) => {
                 panic!("expected error, received events: '{:?}'", events);
@@ -150,6 +194,3 @@ impl<A: Aggregate> AggregateResultValidator<A> {
         };
     }
 }
-
-#[cfg(test)]
-mod test_framework_tests {}
