@@ -16,16 +16,20 @@ pub struct TestAggregate {
     tests: Vec<String>,
 }
 
+#[async_trait]
 impl Aggregate for TestAggregate {
     type Command = TestCommand;
     type Event = TestEvent;
     type Error = UserErrorPayload;
 
-    fn aggregate_type() -> &'static str {
-        "TestAggregate"
+    fn aggregate_type() -> String {
+        "TestAggregate".to_string()
     }
 
-    fn handle(&self, command: TestCommand) -> Result<Vec<TestEvent>, AggregateError<Self::Error>> {
+    async fn handle(
+        &self,
+        command: TestCommand,
+    ) -> Result<Vec<TestEvent>, AggregateError<Self::Error>> {
         match &command {
             TestCommand::CreateTest(command) => {
                 let event = TestEvent::Created(Created {
@@ -103,16 +107,16 @@ pub struct SomethingElse {
 }
 
 impl DomainEvent for TestEvent {
-    fn event_type(&self) -> &'static str {
+    fn event_type(&self) -> String {
         match self {
-            TestEvent::Created(_) => "Created",
-            TestEvent::Tested(_) => "Tested",
-            TestEvent::SomethingElse(_) => "SomethingElse",
+            TestEvent::Created(_) => "Created".to_string(),
+            TestEvent::Tested(_) => "Tested".to_string(),
+            TestEvent::SomethingElse(_) => "SomethingElse".to_string(),
         }
     }
 
-    fn event_version(&self) -> &'static str {
-        "1.0"
+    fn event_version(&self) -> String {
+        "1.0".to_string()
     }
 }
 
@@ -166,9 +170,9 @@ fn metadata() -> HashMap<String, String> {
 async fn test_mem_store() {
     let event_store = MemStore::<TestAggregate>::default();
     let id = "test_id_A";
-    let initial_events = event_store.load(&id).await;
+    let initial_events = event_store.load_events(&id).await.unwrap();
     assert_eq!(0, initial_events.len());
-    let agg_context = event_store.load_aggregate(&id).await;
+    let agg_context = event_store.load_aggregate(&id).await.unwrap();
 
     event_store
         .commit(
@@ -180,9 +184,9 @@ async fn test_mem_store() {
         )
         .await
         .unwrap();
-    let stored_events = event_store.load(&id).await;
+    let stored_events = event_store.load_events(&id).await.unwrap();
     assert_eq!(1, stored_events.len());
-    let agg_context = event_store.load_aggregate(&id).await;
+    let agg_context = event_store.load_aggregate(&id).await.unwrap();
 
     event_store
         .commit(
@@ -202,7 +206,7 @@ async fn test_mem_store() {
         )
         .await
         .unwrap();
-    let stored_envelopes = event_store.load(&id).await;
+    let stored_envelopes = event_store.load_events(&id).await.unwrap();
 
     let mut agg = TestAggregate::default();
     for stored_envelope in stored_envelopes {
@@ -237,7 +241,7 @@ fn test_framework_test() {
         .when(TestCommand::ConfirmTest(ConfirmTest {
             test_name: test_name.to_string(),
         }))
-        .then_expect_error("test already performed")
+        .then_expect_error_message("test already performed")
 }
 
 #[test]
@@ -271,7 +275,7 @@ fn test_framework_failure_test_b() {
         .when(TestCommand::ConfirmTest(ConfirmTest {
             test_name: test_name.to_string(),
         }))
-        .then_expect_error("some error message")
+        .then_expect_error_message("some error message")
 }
 
 #[tokio::test]
@@ -282,7 +286,7 @@ async fn framework_test() {
     let delivered_events = Default::default();
     let view = TestView::new(Arc::clone(&delivered_events));
 
-    let cqrs = CqrsFramework::new(event_store, vec![Arc::new(view)]);
+    let cqrs = CqrsFramework::new(event_store, vec![Box::new(view)]);
     let uuid = uuid::Uuid::new_v4().to_string();
     let id = uuid.clone();
     let metadata = metadata();
